@@ -178,6 +178,7 @@ def get_low_e_ranks(e_arr: np.ndarray, para: dict, is_reverse: bool = False):
 
 
 def get_low_e_xyz(dump_folder: str, add_num: int, old_workbase: str, cutoff_para: dict):
+    dump_folder = os.path.abspath(dump_folder)
     cwd_ = os.getcwd()
     addon_path = str(add_num) + 'addons'
     os.chdir(old_workbase)
@@ -201,6 +202,7 @@ def get_G(atoms: Atoms):
     assert isinstance(G, object)
     return G
 
+
 def lazy_file_mid_name(file_mid_name: str = None):
     if file_mid_name != None:
         file_mid_name = '_' + file_mid_name + '_'
@@ -208,6 +210,7 @@ def lazy_file_mid_name(file_mid_name: str = None):
         file_mid_name = '_'
     return file_mid_name
 
+
 def simple_parse_logs(dump_root: str, src_root: str, mode: str,
                       group: str = None, cage_size: int = None,
                       file_mid_name: str = None):
@@ -296,6 +299,8 @@ def get_connection(xyz_root: str, connection_dump: str, step: int, file_mid_name
     """
     Get connection infos for simple_parse_logs function outputs.
     """
+    xyz_root = os.path.abspath(xyz_root)
+    connection_dump = os.path.abspath(connection_dump)
     cwd_ = os.getcwd()
     os.makedirs(connection_dump, exist_ok=True)
     file_mid_name = lazy_file_mid_name(file_mid_name)
@@ -355,8 +360,8 @@ def simple_dump_pathway(pathway_info_path: str, dump_root: str, src_xyz_root: st
         for a_name in a_pathway:
             shutil.copy(src=a_name, dst=os.path.join(a_sub_dump, a_name))
         os.chdir(a_sub_dump)
-        for a_file in os.listdir('./').copy():
-            with open('traj.log', 'a') as f_w, open(a_file, 'r') as f_r:
+        for a_name in a_pathway:
+            with open('traj.log', 'a') as f_w, open(a_name, 'r') as f_r:
                 for a_line in f_r.readlines():
                     f_w.write(a_line)
     os.chdir(cwd_)
@@ -364,14 +369,15 @@ def simple_dump_pathway(pathway_info_path: str, dump_root: str, src_xyz_root: st
 
 def get_pathway_info(e_info_path: str, xyz_root: str, cnt_root: str, dump_info_path: str, file_mid_name: str = None):
     cwd_ = os.getcwd()
+
     def _get_path_way_unit(idx: int, name_list: list, rel_e_list: list):
-        an_add = add_num_list[idx]
         if idx == -1:
             all_name_list.append(name_list)
             all_rel_e_list.append(rel_e_list)
             all_e_area_list.append(sum(rel_e_list))
             return
         else:
+            an_add = add_num_list[idx]
             a_min_e = min_e_list[idx]
             for a_rank in range(max_rank):
                 file_name = f'{an_add}_addons{file_mid_name}{a_rank + 1}.xyz'
@@ -385,7 +391,7 @@ def get_pathway_info(e_info_path: str, xyz_root: str, cnt_root: str, dump_info_p
                     name_list = [file_name, *name_list]
                     rel = e_info[an_add][a_rank] - a_min_e
                     rel_e_list = [rel, *rel_e_list]
-                    _get_path_way_unit(idx=idx - 1, name_list=name_list, rel_e_list=rel_e_list)
+                    _get_path_way_unit(idx=idx - 1, name_list=name_list.copy(), rel_e_list=rel_e_list.copy())
                     del rel_e_list[0]
                     del name_list[0]
 
@@ -397,22 +403,24 @@ def get_pathway_info(e_info_path: str, xyz_root: str, cnt_root: str, dump_info_p
     add_num_list = sorted(list(e_info.columns))
     min_e_list = []
     max_rank = 0
-    for an_add in add_num_list:
-        min_e_list.append(e_info[an_add][0])
-        max_rank = max(max_rank, len(e_info[an_add]))
+    for a_max_add in add_num_list:
+        min_e_list.append(e_info[a_max_add][0])
+        max_rank = max(max_rank, len(e_info[a_max_add]))
     all_name_list = []
     all_rel_e_list = []
     all_e_area_list = []
-    for idx, a_max_add_e in enumerate(e_info[an_add]):
+    for idx, a_max_add_e in enumerate(e_info[a_max_add]):
         a_max_rel_e = a_max_add_e - min_e_list[-1]
-        a_max_name = f'{an_add}_addons{file_mid_name}{idx + 1}.xyz'
+        a_max_name = f'{a_max_add}_addons{file_mid_name}{idx + 1}.xyz'
         _get_path_way_unit(idx=len(add_num_list) - 2, name_list=[a_max_name], rel_e_list=[a_max_rel_e])
+    all_e_area_list = np.array(all_e_area_list) - min(all_e_area_list)
     info = pd.DataFrame({'name': all_name_list, 'rel_e': all_rel_e_list, 'e_area': all_e_area_list})
     info = info.sort_values(by='e_area')
     info.index = sorted(info.index)
     info.to_pickle(path=dump_info_path)
     os.chdir(cwd_)
 
+
 def map_SWR(q_atoms: Atoms, tgt_atoms: Atoms):
     """
     Currently only support single SWR scenario.
